=======
Infobot
=======


.. image:: https://img.shields.io/pypi/v/infobot.svg
        :target: https://pypi.python.org/pypi/infobot

.. image:: https://img.shields.io/travis/otuk/infobot.svg
        :target: https://travis-ci.org/otuk/infobot

.. image:: https://readthedocs.org/projects/infobot/badge/?version=latest
        :target: https://infobot.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Infobot is an extensible social media posting bot.  Initial version will target Mastodon and will post information on coding.


* Free software: MIT license
* Documentation: https://infobot.readthedocs.io.


Features
--------

* TODO

Credits
-------


